@@ -7,11 +7,10 @@ import traceback
 import time
 import inspect
 import os.path
+import functools
 
 from callback import Callback, defer
 
-from twisted_utils import mergeFunctionMetadata
-
 try:
     from twisted.python.failure import Failure as TwistedFailure
     from twisted.internet.defer import Deferred as TwistedDeferred
@@ -242,20 +241,20 @@ def _o(f):
                 # this too
                 raise Exception('fail')
     """
+    @functools.wraps(f)
     def unwindGenerator(*args, **kwargs):
         return maybeCallbackGenerator(f, *args, **kwargs)
-    return mergeFunctionMetadata(f, unwindGenerator)
+    return unwindGenerator
 o = _o
 
 
-def log_exception(e=None, elide_internals=tracebacks_elide_internals):
-    if e is None:
-        e = sys.exc_info()[1]
+def log_exception(msg="", elide_internals=tracebacks_elide_internals):
+    e = sys.exc_info()[1]
 
     if hasattr(e, '_monocle'):
-        log.error("%s\n%s", str(e), format_tb(e, elide_internals=elide_internals))
+        log.error("%s\n%s", msg, format_tb(e, elide_internals=elide_internals))
     else:
-        log.exception(e)
+        log.exception(msg)
 
 
 @_o
